# eric7.EricWidgets.EricClickableLabel

Module implementing a clickable label.

### Global Attributes

None

### Classes

EricClickableLabel | Class implementing a clickable label.

### Functions

None

## EricClickableLabel

Class implementing a clickable label.

### Signals

clicked(QPoint)
  emitted upon a click on the label with the left button
middleClicked(QPoint)
  emitted upon a click on the label with the middle button or CTRL and left button

### Derived from

QLabel

### Class Attributes

None

### Class Methods

None

### Methods

EricClickableLabel | Constructor
mouseReleaseEvent | Protected method handling mouse release events.

### Static Methods

None

#### EricClickableLabel (Constructor)

EricClickableLabel(parent=None)

Constructor

parent
  reference to the parent widget (QWidget)

#### EricClickableLabel.mouseReleaseEvent

mouseReleaseEvent(evt)

Protected method handling mouse release events.

evt
  mouse event (QMouseEvent)

Up